@@ -1,21 +1,20 @@
 /* gtkam-tree.c
  *
- * Copyright  2001 Lutz Mller <lutz@users.sf.net>
+ * Copyright 2001,2002 Lutz Mueller <lutz@users.sf.net>
+ * Copyright 2004      Andrew Burton <adburton@users.sourceforge.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -23,6 +22,8 @@
 #include "i18n.h"
 
 #include <stdio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <string.h>
 #include <stdlib.h>
 #include <libgen.h>
@@ -1521,7 +1522,9 @@ gtkam_tree_save (GtkamTree *tree)
 	n = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (tree->priv->store),
 					    NULL);
 	for (i = 0; i < n; i++) {
+#ifdef HAVE_GP_PORT_INFO_GET_NAME
 		char *xpath;
+#endif
 		gtk_tree_model_iter_nth_child (
 					GTK_TREE_MODEL (tree->priv->store),
 					&child, NULL, i);
@@ -1529,11 +1532,6 @@ gtkam_tree_save (GtkamTree *tree)
 
 		gp_camera_get_abilities (camera->camera, &a);
 		gp_camera_get_port_info (camera->camera, &info);
-#if 0
-		gp_port_info_get_path (info, &xpath);
-#else
-		xpath = info.path;
-#endif
 		speed = gp_camera_get_port_speed (camera->camera);
 
 		ms = g_strdup_printf ("model-%i", i + 1);
@@ -1541,7 +1539,12 @@ gtkam_tree_save (GtkamTree *tree)
 		g_free (ms);
 
 		ms = g_strdup_printf ("port-%i", i + 1);
+#ifdef HAVE_GP_PORT_INFO_GET_NAME
+		gp_port_info_get_path (info, &xpath);
 		gp_setting_set ("gtkam", ms, xpath);
+#else
+		gp_setting_set ("gtkam", ms, info.path);
+#endif
 		g_free (ms);
 
 		ms = g_strdup_printf ("multi-%i", i + 1);
